@@ -7,9 +7,13 @@ fn main() {
         println!("cargo:rustc-link-search={}", out.display());
         let device_file = if env::var_os("CARGO_FEATURE_PIC32MX2XXFXXXB").is_some() {
             "src/pic32mx2xxfxxxb/device.x"
+        } else if env::var_os("CARGO_FEATURE_PIC32MX2XXFXXXC").is_some() {
+            "src/pic32mx2xxfxxxc/device.x"
         } else if env::var_os("CARGO_FEATURE_PIC32MX2XXFXXXD").is_some() {
             "src/pic32mx2xxfxxxd/device.x"
-        } else { panic!("No device features selected"); };
+        } else {
+            panic!("No device features selected");
+        };
         fs::copy(device_file, out.join("device.x")).unwrap();
         println!("cargo:rerun-if-changed={}", device_file);
     }
